@@ -1,7 +1,10 @@
-# coding=utf-8
-
+from gettext import gettext as _
 import logging
-from blueman.bluez.Network import AnyNetwork
+from typing import List, Any
+
+from gi.repository import GLib
+
+from blueman.bluez.Network import AnyNetwork, Network
 from blueman.gui.Notification import Notification
 from blueman.plugins.AppletPlugin import AppletPlugin
 from blueman.main.DBusProxies import Mechanism
@@ -14,30 +17,32 @@ class DhcpClient(AppletPlugin):
 
     _any_network = None
 
-    def on_load(self):
+    def on_load(self) -> None:
         self._any_network = AnyNetwork()
         self._any_network.connect_signal('property-changed', self._on_network_prop_changed)
 
-        self.quering = []
+        self.quering: List[str] = []
 
         self._add_dbus_method("DhcpClient", ("s",), "", self.dhcp_acquire)
 
-    def on_unload(self):
+    def on_unload(self) -> None:
         del self._any_network
 
-    def _on_network_prop_changed(self, _network, key, value, _path):
+    def _on_network_prop_changed(self, _network: AnyNetwork, key: str, value: Any, object_path: str) -> None:
         if key == "Interface":
             if value != "":
-                self.dhcp_acquire(value)
+                self.dhcp_acquire(object_path)
+
+    def dhcp_acquire(self, object_path: str) -> None:
+        device = Network(obj_path=object_path)["Interface"]
 
-    def dhcp_acquire(self, device):
         if device not in self.quering:
             self.quering.append(device)
         else:
             return
 
         if device != "":
-            def reply(_obj, result, _user_data):
+            def reply(_obj: Mechanism, result: str, _user_data: None) -> None:
                 logging.info(result)
                 Notification(_("Bluetooth Network"),
                              _("Interface %(0)s bound to IP address %(1)s") % {"0": device, "1": result},
@@ -45,7 +50,7 @@ class DhcpClient(AppletPlugin):
 
                 self.quering.remove(device)
 
-            def err(_obj, result, _user_data):
+            def err(_obj: Mechanism, result: GLib.Error, _user_data: None) -> None:
                 logging.warning(result)
                 Notification(_("Bluetooth Network"), _("Failed to obtain an IP address on %s") % device,
                              icon_name="network-workgroup").show()
@@ -56,4 +61,4 @@ class DhcpClient(AppletPlugin):
                          icon_name="network-workgroup").show()
 
             m = Mechanism()
-            m.DhcpClient('(s)', device, result_handler=reply, error_handler=err, timeout=120 * 1000)
+            m.DhcpClient('(s)', object_path, result_handler=reply, error_handler=err, timeout=120 * 1000)
