@@ -1,12 +1,11 @@
-# coding=utf-8
+from gettext import gettext as _
 from random import randint
-from locale import bind_textdomain_codeset
 import logging
 import ipaddress
+from typing import List, Tuple, cast, Union, TYPE_CHECKING
 
-from blueman.Constants import *
-from blueman.Functions import have
-from _blueman import get_net_interfaces, get_net_address, get_net_netmask
+from blueman.Functions import have, get_local_interfaces
+from blueman.main.Builder import Builder
 from blueman.plugins.ServicePlugin import ServicePlugin
 from blueman.main.NetConf import NetConf, DnsMasqHandler, DhcpdHandler, UdhcpdHandler
 from blueman.main.Config import Config
@@ -16,27 +15,28 @@ from blueman.gui.CommonUi import ErrorDialog
 
 import gi
 gi.require_version("Gtk", "3.0")
-from gi.repository import Gio, Gtk
+from gi.repository import Gio, Gtk, GObject
+
+if TYPE_CHECKING:
+    from typing_extensions import Literal
 
 
 class Network(ServicePlugin):
     __plugin_info__ = (_("Network"), "network-workgroup")
 
-    def on_load(self, container):
+    def on_load(self, container: Gtk.Box) -> None:
 
-        self.Builder = Gtk.Builder()
-        self.Builder.set_translation_domain("blueman")
-        bind_textdomain_codeset("blueman", "UTF-8")
-        self.Builder.add_from_file(UI_PATH + "/services-network.ui")
-        self.widget = self.Builder.get_object("network_frame")
+        self._builder = Builder("services-network.ui")
+        self.widget = self._builder.get_widget("network_frame", Gtk.Widget)
 
         container.pack_start(self.widget, True, True, 0)
 
-        self.interfaces = []
-        for iface in get_net_interfaces():
+        self.interfaces: List[Tuple[str, ipaddress.IPv4Interface]] = []
+        netifs = get_local_interfaces()
+        for iface in netifs:
             if iface != "lo" and iface != "pan1":
                 logging.info(iface)
-                ipiface = ipaddress.ip_interface('/'.join((get_net_address(iface), get_net_netmask(iface))))
+                ipiface = ipaddress.ip_interface('/'.join(cast(Tuple[str, str], netifs[iface])))
                 self.interfaces.append((iface, ipiface))
 
         self.setup_network()
@@ -44,31 +44,30 @@ class Network(ServicePlugin):
             self.ip_check()
         except (ValueError, ipaddress.AddressValueError) as e:
             logging.exception(e)
-        return _("Network"), "network-workgroup"
 
-    def on_enter(self):
+    def on_enter(self) -> None:
         self.widget.props.visible = True
 
-    def on_leave(self):
+    def on_leave(self) -> None:
         self.widget.props.visible = False
 
-    def on_apply(self):
+    def on_apply(self) -> None:
 
         if self.on_query_apply_state():
             logging.info("network apply")
 
             m = Mechanism()
-            nap_enable = self.Builder.get_object("nap-enable")
+            nap_enable = self._builder.get_widget("nap-enable", Gtk.CheckButton)
             if nap_enable.props.active:
 
-                if self.Builder.get_object("r_dhcpd").props.active:
+                if self._builder.get_widget("r_dhcpd", Gtk.RadioButton).props.active:
                     stype = "DhcpdHandler"
-                elif self.Builder.get_object("r_dnsmasq").props.active:
+                elif self._builder.get_widget("r_dnsmasq", Gtk.RadioButton).props.active:
                     stype = "DnsMasqHandler"
-                elif self.Builder.get_object("r_udhcpd").props.active:
+                elif self._builder.get_widget("r_udhcpd", Gtk.RadioButton).props.active:
                     stype = "UdhcpdHandler"
 
-                net_ip = self.Builder.get_object("net_ip")
+                net_ip = self._builder.get_widget("net_ip", Gtk.Entry)
 
                 try:
                     m.EnableNetwork('(sss)', net_ip.props.text, "255.255.255.0", stype)
@@ -76,8 +75,9 @@ class Network(ServicePlugin):
                     if not self.Config["nap-enable"]:
                         self.Config["nap-enable"] = True
                 except Exception as e:
-                    d = ErrorDialog("<b>Failed to apply network settings</b>",
-                                    excp=e, parent=self.widget.get_toplevel())
+                    parent = self.widget.get_toplevel()
+                    assert isinstance(parent, Gtk.Container)
+                    d = ErrorDialog("<b>Failed to apply network settings</b>", excp=e, parent=parent)
 
                     d.run()
                     d.destroy()
@@ -88,8 +88,8 @@ class Network(ServicePlugin):
 
             self.clear_options()
 
-    def ip_check(self):
-        entry = self.Builder.get_object("net_ip")
+    def ip_check(self) -> None:
+        entry = self._builder.get_widget("net_ip", Gtk.Entry)
         try:
             nap_ipiface = ipaddress.ip_interface('/'.join((entry.props.text, '255.255.255.0')))
         except (ValueError, ipaddress.AddressValueError):
@@ -115,7 +115,7 @@ class Network(ServicePlugin):
 
         entry.props.secondary_icon_name = None
 
-    def on_query_apply_state(self):
+    def on_query_apply_state(self) -> Union[bool, "Literal[-1]"]:
         opts = self.get_options()
         if not opts:
             return False
@@ -129,21 +129,21 @@ class Network(ServicePlugin):
 
         return True
 
-    def setup_network(self):
+    def setup_network(self) -> None:
         self.Config = Config("org.blueman.network")
 
-        nap_enable = self.Builder.get_object("nap-enable")
-        r_dnsmasq = self.Builder.get_object("r_dnsmasq")
-        r_dhcpd = self.Builder.get_object("r_dhcpd")
-        r_udhcpd = self.Builder.get_object("r_udhcpd")
-        net_ip = self.Builder.get_object("net_ip")
-        rb_nm = self.Builder.get_object("rb_nm")
-        rb_blueman = self.Builder.get_object("rb_blueman")
-        rb_dun_nm = self.Builder.get_object("rb_dun_nm")
-        rb_dun_blueman = self.Builder.get_object("rb_dun_blueman")
+        nap_enable = self._builder.get_widget("nap-enable", Gtk.CheckButton)
+        r_dnsmasq = self._builder.get_widget("r_dnsmasq", Gtk.RadioButton)
+        r_dhcpd = self._builder.get_widget("r_dhcpd", Gtk.RadioButton)
+        r_udhcpd = self._builder.get_widget("r_udhcpd", Gtk.RadioButton)
+        net_ip = self._builder.get_widget("net_ip", Gtk.Entry)
+        rb_nm = self._builder.get_widget("rb_nm", Gtk.RadioButton)
+        rb_blueman = self._builder.get_widget("rb_blueman", Gtk.RadioButton)
+        rb_dun_nm = self._builder.get_widget("rb_dun_nm", Gtk.RadioButton)
+        rb_dun_blueman = self._builder.get_widget("rb_dun_blueman", Gtk.RadioButton)
 
-        nap_frame = self.Builder.get_object("nap_frame")
-        warning = self.Builder.get_object("warning")
+        nap_frame = self._builder.get_widget("nap_frame", Gtk.Frame)
+        warning = self._builder.get_widget("warning", Gtk.Box)
 
         if not self.Config["nap-enable"]:
             nap_frame.props.sensitive = False
@@ -203,14 +203,14 @@ class Network(ServicePlugin):
 
         self.Config.bind_to_widget("nap-enable", nap_enable, "active", Gio.SettingsBindFlags.GET)
 
-        nap_enable.bind_property("active", nap_frame, "sensitive", 0)
+        nap_enable.bind_property("active", nap_frame, "sensitive", GObject.BindingFlags.DEFAULT)
 
         applet = AppletService()
 
         avail_plugins = applet.QueryAvailablePlugins()
         active_plugins = applet.QueryPlugins()
 
-        def dun_support_toggled(rb, x):
+        def dun_support_toggled(rb: Gtk.RadioButton, x: str) -> None:
             if rb.props.active and x == "nm":
                 applet.SetPluginConfig('(sb)', "PPPSupport", False)
                 applet.SetPluginConfig('(sb)', "NMDUNSupport", True)
@@ -218,7 +218,7 @@ class Network(ServicePlugin):
                 applet.SetPluginConfig('(sb)', "NMDUNSupport", False)
                 applet.SetPluginConfig('(sb)', "PPPSupport", True)
 
-        def pan_support_toggled(rb, x):
+        def pan_support_toggled(rb: Gtk.RadioButton, x: str) -> None:
             if rb.props.active and x == "nm":
                 applet.SetPluginConfig('(sb)', "DhcpClient", False)
                 applet.SetPluginConfig('(sb)', "NMPANSupport", True)
